panicsel-developers Mailing List for Panicsel IPMI project (Page 2)
Brought to you by:
arcress
You can subscribe to this list here.
| 2002 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
|
Oct
(9) |
Nov
(6) |
Dec
(6) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2003 |
Jan
(3) |
Feb
(5) |
Mar
(12) |
Apr
(4) |
May
|
Jun
(4) |
Jul
(1) |
Aug
|
Sep
(7) |
Oct
(3) |
Nov
|
Dec
(1) |
| 2004 |
Jan
(1) |
Feb
(1) |
Mar
|
Apr
(3) |
May
|
Jun
(7) |
Jul
(9) |
Aug
(3) |
Sep
|
Oct
|
Nov
|
Dec
|
| 2005 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
(2) |
Oct
|
Nov
|
Dec
|
|
From: Cress, A. R <and...@in...> - 2004-01-20 15:31:03
|
A new panicsel 1.4.0 release has been posted to sourceforge. =20
Here are the changes from the previous version:
01/15/04 ARCress ver 1.4.0
ipmicmd.c added more SEvt commands
ipmicmd.h added more SEvt commands
sensor v1.12 fixed SetThreshold to set hysteresis
sensor.8 more desription on set threshold parameters
UserGuide updates sensor man page, added completion codes
README updated with current man page filenames
showsel v1.17 more sens_desc for Fans
See http://panicsel.sourceforge.net for the full ChangeLog and more
information.
Let me know if you have any change requests or problems.
Andy
|
|
From: Cress, A. R <and...@in...> - 2003-12-10 16:09:09
|
A new panicsel 1.3.8 release has been posted to sourceforge. There is only one change from the previous release: pefconfig v1.22 fixed auth type enables for ServerConfig See http://panicsel.sourceforge.net for the full ChangeLog and more information. Let me know if you have any change requests or problems. Andy |
|
From: Cress, A. R <and...@in...> - 2003-10-30 19:41:30
|
New panicsel release 1.3.7 files are now on sourceforge.
Here are the changes in this release.
10/29/03 ARCress ver 1.3.7
pefconfig v1.21 added option -D for DHCP
pefconfig.8 added option -D
sensor v1.10 added options to set thresholds
sensor v1.11 fixed offset for show thresholds
sensor.8 documented threshold options
showsel v1.16 add more sens_desc strings (for boot)
wdt v1.3 fixed cc error in set_wdt (idata size) =20
Andy
|
|
From: Cress, A. R <and...@in...> - 2003-10-20 15:45:35
|
Tirumal, On a 'normal' system, the times in the SEL from showsel will match the Linux OS time within a few seconds. The SEL gets its time from the BIOS clock. There are a few things which could cause this to be mismatched. 1) OS & Firmware times not sync'd: When installing Linux, the OS time should be set to sync with the BIOS time. In RedHat install, this is via the "Sync with GMT time" checkbox (or soemthing like that)=20 on the time zone menu. Otherwise, the actual times could stray apart.=20 I usually set the time sync during install, so I'm not sure how to set it afterward, but=20 I believe that it can be done. 2) Sometimes the Linux system time is off/inaccurate, and can lose several minutes, even=20 hours over a long period of time due to enough interrupts occurring to miss some timer=20 interrupts. If the BIOS time is not sync'd with the OS, the BIOS time will=20 be more accurate, but different. =20 or 3) The BIOS system time was never set. If you clear CMOS for some reason, this would=20 need to be set again. =20 Andy -----Original Message----- From: pan...@li... [mailto:pan...@li...] On Behalf Of tirumal b Sent: Sunday, October 19, 2003 9:48 PM To: pan...@li... Subject: [Panicsel-developers] SEL time Hello All, The time the event happens is not the same as the event occured when i see show_sel output. I rebooted the machine and ran show_sel, it shows the last boot event to be 8:42 but it was around 1:00. There is no problem with the system time or the firmware, i checked those. Can u tell me what is the problem. Thank you Tirumal __________________________________ Do you Yahoo!? The New Yahoo! Shopping - with improved product search http://shopping.yahoo.com ------------------------------------------------------- This SF.net email sponsored by: Enterprise Linux Forum Conference & Expo The Event For Linux Datacenter Solutions & Strategies in The Enterprise=20 Linux in the Boardroom; in the Front Office; & in the Server Room=20 http://www.enterpriselinuxforum.com _______________________________________________ Panicsel-developers mailing list Pan...@li... https://lists.sourceforge.net/lists/listinfo/panicsel-developers |
|
From: tirumal b <tir...@ya...> - 2003-10-20 03:36:19
|
Hello All, The time the event happens is not the same as the event occured when i see show_sel output. I rebooted the machine and ran show_sel, it shows the last boot event to be 8:42 but it was around 1:00. There is no problem with the system time or the firmware, i checked those. Can u tell me what is the problem. Thank you Tirumal __________________________________ Do you Yahoo!? The New Yahoo! Shopping - with improved product search http://shopping.yahoo.com |
|
From: Zheng, J. <jef...@in...> - 2003-09-26 00:42:02
|
I think CPCI and future ATCA need it. Thanks Jeff Jef...@in... BTW, I speak for myself, not for Intel Corp. -----Original Message----- From: pan...@li... [mailto:pan...@li...]On Behalf Of Cress, Andrew R Sent: Thursday, September 25, 2003 10:28 PM To: Zheng, Jeff; pan...@li... Subject: RE: [Panicsel-developers] support FRU from Device Locator Record Jeff, I could, if I had a platform to test it on. All of my platforms have FRU/SDR set through the BMC. What platform are you targeting for this? Andy -----Original Message----- From: pan...@li... [mailto:pan...@li...] On Behalf Of Zheng, Jeff Sent: Thursday, September 25, 2003 2:54 AM To: Cress, Andrew R; pan...@li... Subject: [Panicsel-developers] support FRU from Device Locator Record Andy It seems that fruconfig does not support FRU from Device Locator Record, do you plan to support it? Thanks Jeff Jef...@in... BTW, I speak for myself, not for Intel Corp. > -----Original Message----- > From: Cress, Andrew R=20 > Sent: 2003?9?9? 21:35 > To: Zheng, Jeff > Subject: RE: [Panicsel-developers] fruconfig fails on Langley >=20 >=20 > Jeff, >=20 > Well, that explains why fruconfig gets an error, there was=20 > somehow a fru write with a bad checksum. All of the FRU=20 > functions should return errors. You will have to manually=20 > force the FRU update from diskette 2, with the following command: >=20 > FRUSDR /FRU TSR2BMC6.FRU >=20 > It should be fixed after that. >=20 > Andy >=20 > -----Original Message----- > From: Zheng, Jeff=20 > Sent: Tuesday, September 09, 2003 5:12 AM > To: Cress, Andrew R > Subject: RE: [Panicsel-developers] fruconfig fails on Langley >=20 >=20 > Andy, >=20 > No, I downloaded TSRxT2_Sup21.exe and installed 3 disks (BMC=20 > fireware/FRU update/BIOS update). But it still fails: > [root@hpi util]# ./fruconfig > fruconfig: version 1.5 > -- BMC version 0.63, IPMI version 1.5 > Mainboard FRU Size : 256 > FRU size out of bounds: available=3D256 used=3D1832 > Please apply the correct FRU/SDR diskette > show_fru error -1 >=20 > Notes: When I update FRU(disk 2), it dispalyed messages: > FRU IMBDEVICE on bus FFh, Device ID 00h, IPMB address: 20h, LUN 00 > Warning, FRU EEPROM common Header Area Checksum is invalid > Error, file and EEPROM header areas must be identical, but=20 > are different. >=20 >=20 > But the installation complete succefully. >=20 >=20 > Thanks > Jeff Jef...@in... > BTW, I speak for myself, not for Intel Corp. >=20 >=20 > > -----Original Message----- > > From: Cress, Andrew R=20 > > Sent: 2003?9?9? 4:16 > > To: Zheng, Jeff > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > >=20 > >=20 > > Jeff, > >=20 > > Did you get your system fixed ok? > >=20 > > Andy > >=20 > > -----Original Message----- > > From: Cress, Andrew R=20 > > Sent: Wednesday, September 03, 2003 2:06 PM > > To: Zheng, Jeff; pan...@li... > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > >=20 > >=20 > > Jeff, > >=20 > > This is how the FRU/SDR data is initialized for each platform. > > There are diskettes for BIOS, BMC, and FRU/SDR for each platform. > > A version of the FRU/SDR diskette image is on the Resource=20 > CD, or you > > can download=20 > > the latest versions from http://support.intel.com by platform. > >=20 > > BMC 48 for the Langley platform is a pre-release version. =20 > > That should work ok with FRU/SDR 5.0J or later, but if you want to > > upgrade the BIOS, BMC and FRU/SDR you can download newer ones. > >=20 > > Andy > >=20 > > -----Original Message----- > > From: Zheng, Jeff=20 > > Sent: Tuesday, September 02, 2003 8:40 PM > > To: Cress, Andrew R; pan...@li... > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > >=20 > >=20 > > Andy, > >=20 > > What's the FRU/SDR diskette? > >=20 > > Thanks > > Jeff Jef...@in... > > BTW, I speak for myself, not for Intel Corp. > >=20 > >=20 > > > -----Original Message----- > > > From: Cress, Andrew R=20 > > > Sent: 2003?9?3? 1:44 > > > To: Zheng, Jeff; pan...@li... > > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > > >=20 > > >=20 > > > Jeff, > > >=20 > > > That size returned isn't valid. The most likely cause is, as=20 > > > the utility message says, a wrong FRU/SDR diskette. =20 > > > fruconfig works on all Langleys except this one, and that=20 > > > must be the difference. > > > The version should have been one that goes with BMC 48. =20 > > > Which version of the FRU/SDR diskette was used on this system? > > >=20 > > > Andy > > >=20 > > > -----Original Message----- > > > From: Zheng, Jeff=20 > > > Sent: Tuesday, September 02, 2003 4:06 AM > > > To: pan...@li... > > > Subject: [Panicsel-developers] fruconfig fails on Langley > > >=20 > > >=20 > > > Andy, > > >=20 > > > I run fruconfig on Langley and it fails. Here is the result: > > > [root@hpi util]# ./fruconfig > > > fruconfig: version 1.5 > > > -- BMC version 0.48, IPMI version 1.5 > > > Mainboard FRU Size : 256 > > > FRU size out of bounds: available=3D256 used=3D1832 > > > Please apply the correct FRU/SDR diskette > > > show_fru error -1 > > >=20 > > > Attached file is output from ./fruconfig -x > > >=20 > > > From SSU, the Langley contains 10 FRU items, meanwhile 2 FRU=20 > > > items are displayable. > > >=20 > > > Thanks > > > Jeff Jef...@in... > > > BTW, I speak for myself, not for Intel Corp. > > >=20 > >=20 > >=20 > > ------------------------------------------------------- > > This sf.net email is sponsored by:ThinkGeek > > Welcome to geek heaven. > > http://thinkgeek.com/sf > > _______________________________________________ > > Panicsel-developers mailing list > > Pan...@li... > > https://lists.sourceforge.net/lists/listinfo/panicsel-developers > >=20 >=20 ------------------------------------------------------- This sf.net email is sponsored by:ThinkGeek Welcome to geek heaven. http://thinkgeek.com/sf _______________________________________________ Panicsel-developers mailing list Pan...@li... https://lists.sourceforge.net/lists/listinfo/panicsel-developers ------------------------------------------------------- This sf.net email is sponsored by:ThinkGeek Welcome to geek heaven. http://thinkgeek.com/sf _______________________________________________ Panicsel-developers mailing list Pan...@li... https://lists.sourceforge.net/lists/listinfo/panicsel-developers |
|
From: Cress, A. R <and...@in...> - 2003-09-25 14:28:40
|
Jeff, I could, if I had a platform to test it on. All of my platforms have FRU/SDR set through the BMC. What platform are you targeting for this? Andy -----Original Message----- From: pan...@li... [mailto:pan...@li...] On Behalf Of Zheng, Jeff Sent: Thursday, September 25, 2003 2:54 AM To: Cress, Andrew R; pan...@li... Subject: [Panicsel-developers] support FRU from Device Locator Record Andy It seems that fruconfig does not support FRU from Device Locator Record, do you plan to support it? Thanks Jeff Jef...@in... BTW, I speak for myself, not for Intel Corp. > -----Original Message----- > From: Cress, Andrew R=20 > Sent: 2003?9?9? 21:35 > To: Zheng, Jeff > Subject: RE: [Panicsel-developers] fruconfig fails on Langley >=20 >=20 > Jeff, >=20 > Well, that explains why fruconfig gets an error, there was=20 > somehow a fru write with a bad checksum. All of the FRU=20 > functions should return errors. You will have to manually=20 > force the FRU update from diskette 2, with the following command: >=20 > FRUSDR /FRU TSR2BMC6.FRU >=20 > It should be fixed after that. >=20 > Andy >=20 > -----Original Message----- > From: Zheng, Jeff=20 > Sent: Tuesday, September 09, 2003 5:12 AM > To: Cress, Andrew R > Subject: RE: [Panicsel-developers] fruconfig fails on Langley >=20 >=20 > Andy, >=20 > No, I downloaded TSRxT2_Sup21.exe and installed 3 disks (BMC=20 > fireware/FRU update/BIOS update). But it still fails: > [root@hpi util]# ./fruconfig > fruconfig: version 1.5 > -- BMC version 0.63, IPMI version 1.5 > Mainboard FRU Size : 256 > FRU size out of bounds: available=3D256 used=3D1832 > Please apply the correct FRU/SDR diskette > show_fru error -1 >=20 > Notes: When I update FRU(disk 2), it dispalyed messages: > FRU IMBDEVICE on bus FFh, Device ID 00h, IPMB address: 20h, LUN 00 > Warning, FRU EEPROM common Header Area Checksum is invalid > Error, file and EEPROM header areas must be identical, but=20 > are different. >=20 >=20 > But the installation complete succefully. >=20 >=20 > Thanks > Jeff Jef...@in... > BTW, I speak for myself, not for Intel Corp. >=20 >=20 > > -----Original Message----- > > From: Cress, Andrew R=20 > > Sent: 2003?9?9? 4:16 > > To: Zheng, Jeff > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > >=20 > >=20 > > Jeff, > >=20 > > Did you get your system fixed ok? > >=20 > > Andy > >=20 > > -----Original Message----- > > From: Cress, Andrew R=20 > > Sent: Wednesday, September 03, 2003 2:06 PM > > To: Zheng, Jeff; pan...@li... > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > >=20 > >=20 > > Jeff, > >=20 > > This is how the FRU/SDR data is initialized for each platform. > > There are diskettes for BIOS, BMC, and FRU/SDR for each platform. > > A version of the FRU/SDR diskette image is on the Resource=20 > CD, or you > > can download=20 > > the latest versions from http://support.intel.com by platform. > >=20 > > BMC 48 for the Langley platform is a pre-release version. =20 > > That should work ok with FRU/SDR 5.0J or later, but if you want to > > upgrade the BIOS, BMC and FRU/SDR you can download newer ones. > >=20 > > Andy > >=20 > > -----Original Message----- > > From: Zheng, Jeff=20 > > Sent: Tuesday, September 02, 2003 8:40 PM > > To: Cress, Andrew R; pan...@li... > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > >=20 > >=20 > > Andy, > >=20 > > What's the FRU/SDR diskette? > >=20 > > Thanks > > Jeff Jef...@in... > > BTW, I speak for myself, not for Intel Corp. > >=20 > >=20 > > > -----Original Message----- > > > From: Cress, Andrew R=20 > > > Sent: 2003?9?3? 1:44 > > > To: Zheng, Jeff; pan...@li... > > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > > >=20 > > >=20 > > > Jeff, > > >=20 > > > That size returned isn't valid. The most likely cause is, as=20 > > > the utility message says, a wrong FRU/SDR diskette. =20 > > > fruconfig works on all Langleys except this one, and that=20 > > > must be the difference. > > > The version should have been one that goes with BMC 48. =20 > > > Which version of the FRU/SDR diskette was used on this system? > > >=20 > > > Andy > > >=20 > > > -----Original Message----- > > > From: Zheng, Jeff=20 > > > Sent: Tuesday, September 02, 2003 4:06 AM > > > To: pan...@li... > > > Subject: [Panicsel-developers] fruconfig fails on Langley > > >=20 > > >=20 > > > Andy, > > >=20 > > > I run fruconfig on Langley and it fails. Here is the result: > > > [root@hpi util]# ./fruconfig > > > fruconfig: version 1.5 > > > -- BMC version 0.48, IPMI version 1.5 > > > Mainboard FRU Size : 256 > > > FRU size out of bounds: available=3D256 used=3D1832 > > > Please apply the correct FRU/SDR diskette > > > show_fru error -1 > > >=20 > > > Attached file is output from ./fruconfig -x > > >=20 > > > From SSU, the Langley contains 10 FRU items, meanwhile 2 FRU=20 > > > items are displayable. > > >=20 > > > Thanks > > > Jeff Jef...@in... > > > BTW, I speak for myself, not for Intel Corp. > > >=20 > >=20 > >=20 > > ------------------------------------------------------- > > This sf.net email is sponsored by:ThinkGeek > > Welcome to geek heaven. > > http://thinkgeek.com/sf > > _______________________________________________ > > Panicsel-developers mailing list > > Pan...@li... > > https://lists.sourceforge.net/lists/listinfo/panicsel-developers > >=20 >=20 ------------------------------------------------------- This sf.net email is sponsored by:ThinkGeek Welcome to geek heaven. http://thinkgeek.com/sf _______________________________________________ Panicsel-developers mailing list Pan...@li... https://lists.sourceforge.net/lists/listinfo/panicsel-developers |
|
From: Zheng, J. <jef...@in...> - 2003-09-25 06:55:01
|
Andy It seems that fruconfig does not support FRU from Device Locator Record, do you plan to support it? Thanks Jeff Jef...@in... BTW, I speak for myself, not for Intel Corp. > -----Original Message----- > From: Cress, Andrew R=20 > Sent: 2003?9?9? 21:35 > To: Zheng, Jeff > Subject: RE: [Panicsel-developers] fruconfig fails on Langley >=20 >=20 > Jeff, >=20 > Well, that explains why fruconfig gets an error, there was=20 > somehow a fru write with a bad checksum. All of the FRU=20 > functions should return errors. You will have to manually=20 > force the FRU update from diskette 2, with the following command: >=20 > FRUSDR /FRU TSR2BMC6.FRU >=20 > It should be fixed after that. >=20 > Andy >=20 > -----Original Message----- > From: Zheng, Jeff=20 > Sent: Tuesday, September 09, 2003 5:12 AM > To: Cress, Andrew R > Subject: RE: [Panicsel-developers] fruconfig fails on Langley >=20 >=20 > Andy, >=20 > No, I downloaded TSRxT2_Sup21.exe and installed 3 disks (BMC=20 > fireware/FRU update/BIOS update). But it still fails: > [root@hpi util]# ./fruconfig > fruconfig: version 1.5 > -- BMC version 0.63, IPMI version 1.5 > Mainboard FRU Size : 256 > FRU size out of bounds: available=3D256 used=3D1832 > Please apply the correct FRU/SDR diskette > show_fru error -1 >=20 > Notes: When I update FRU(disk 2), it dispalyed messages: > FRU IMBDEVICE on bus FFh, Device ID 00h, IPMB address: 20h, LUN 00 > Warning, FRU EEPROM common Header Area Checksum is invalid > Error, file and EEPROM header areas must be identical, but=20 > are different. >=20 >=20 > But the installation complete succefully. >=20 >=20 > Thanks > Jeff Jef...@in... > BTW, I speak for myself, not for Intel Corp. >=20 >=20 > > -----Original Message----- > > From: Cress, Andrew R=20 > > Sent: 2003?9?9? 4:16 > > To: Zheng, Jeff > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > >=20 > >=20 > > Jeff, > >=20 > > Did you get your system fixed ok? > >=20 > > Andy > >=20 > > -----Original Message----- > > From: Cress, Andrew R=20 > > Sent: Wednesday, September 03, 2003 2:06 PM > > To: Zheng, Jeff; pan...@li... > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > >=20 > >=20 > > Jeff, > >=20 > > This is how the FRU/SDR data is initialized for each platform. > > There are diskettes for BIOS, BMC, and FRU/SDR for each platform. > > A version of the FRU/SDR diskette image is on the Resource=20 > CD, or you > > can download=20 > > the latest versions from http://support.intel.com by platform. > >=20 > > BMC 48 for the Langley platform is a pre-release version. =20 > > That should work ok with FRU/SDR 5.0J or later, but if you want to > > upgrade the BIOS, BMC and FRU/SDR you can download newer ones. > >=20 > > Andy > >=20 > > -----Original Message----- > > From: Zheng, Jeff=20 > > Sent: Tuesday, September 02, 2003 8:40 PM > > To: Cress, Andrew R; pan...@li... > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > >=20 > >=20 > > Andy, > >=20 > > What's the FRU/SDR diskette? > >=20 > > Thanks > > Jeff Jef...@in... > > BTW, I speak for myself, not for Intel Corp. > >=20 > >=20 > > > -----Original Message----- > > > From: Cress, Andrew R=20 > > > Sent: 2003?9?3? 1:44 > > > To: Zheng, Jeff; pan...@li... > > > Subject: RE: [Panicsel-developers] fruconfig fails on Langley > > >=20 > > >=20 > > > Jeff, > > >=20 > > > That size returned isn't valid. The most likely cause is, as=20 > > > the utility message says, a wrong FRU/SDR diskette. =20 > > > fruconfig works on all Langleys except this one, and that=20 > > > must be the difference. > > > The version should have been one that goes with BMC 48. =20 > > > Which version of the FRU/SDR diskette was used on this system? > > >=20 > > > Andy > > >=20 > > > -----Original Message----- > > > From: Zheng, Jeff=20 > > > Sent: Tuesday, September 02, 2003 4:06 AM > > > To: pan...@li... > > > Subject: [Panicsel-developers] fruconfig fails on Langley > > >=20 > > >=20 > > > Andy, > > >=20 > > > I run fruconfig on Langley and it fails. Here is the result: > > > [root@hpi util]# ./fruconfig > > > fruconfig: version 1.5 > > > -- BMC version 0.48, IPMI version 1.5 > > > Mainboard FRU Size : 256 > > > FRU size out of bounds: available=3D256 used=3D1832 > > > Please apply the correct FRU/SDR diskette > > > show_fru error -1 > > >=20 > > > Attached file is output from ./fruconfig -x > > >=20 > > > From SSU, the Langley contains 10 FRU items, meanwhile 2 FRU=20 > > > items are displayable. > > >=20 > > > Thanks > > > Jeff Jef...@in... > > > BTW, I speak for myself, not for Intel Corp. > > >=20 > >=20 > >=20 > > ------------------------------------------------------- > > This sf.net email is sponsored by:ThinkGeek > > Welcome to geek heaven. > > http://thinkgeek.com/sf > > _______________________________________________ > > Panicsel-developers mailing list > > Pan...@li... > > https://lists.sourceforge.net/lists/listinfo/panicsel-developers > >=20 >=20 |
|
From: Cress, A. R <and...@in...> - 2003-09-03 18:06:34
|
Jeff, This is how the FRU/SDR data is initialized for each platform. There are diskettes for BIOS, BMC, and FRU/SDR for each platform. A version of the FRU/SDR diskette image is on the Resource CD, or you can download=20 the latest versions from http://support.intel.com by platform. BMC 48 for the Langley platform is a pre-release version. =20 That should work ok with FRU/SDR 5.0J or later, but if you want to upgrade the BIOS, BMC and FRU/SDR you can download newer ones. Andy -----Original Message----- From: Zheng, Jeff=20 Sent: Tuesday, September 02, 2003 8:40 PM To: Cress, Andrew R; pan...@li... Subject: RE: [Panicsel-developers] fruconfig fails on Langley Andy, What's the FRU/SDR diskette? Thanks Jeff Jef...@in... BTW, I speak for myself, not for Intel Corp. > -----Original Message----- > From: Cress, Andrew R=20 > Sent: 2003?9?3? 1:44 > To: Zheng, Jeff; pan...@li... > Subject: RE: [Panicsel-developers] fruconfig fails on Langley >=20 >=20 > Jeff, >=20 > That size returned isn't valid. The most likely cause is, as=20 > the utility message says, a wrong FRU/SDR diskette. =20 > fruconfig works on all Langleys except this one, and that=20 > must be the difference. > The version should have been one that goes with BMC 48. =20 > Which version of the FRU/SDR diskette was used on this system? >=20 > Andy >=20 > -----Original Message----- > From: Zheng, Jeff=20 > Sent: Tuesday, September 02, 2003 4:06 AM > To: pan...@li... > Subject: [Panicsel-developers] fruconfig fails on Langley >=20 >=20 > Andy, >=20 > I run fruconfig on Langley and it fails. Here is the result: > [root@hpi util]# ./fruconfig > fruconfig: version 1.5 > -- BMC version 0.48, IPMI version 1.5 > Mainboard FRU Size : 256 > FRU size out of bounds: available=3D256 used=3D1832 > Please apply the correct FRU/SDR diskette > show_fru error -1 >=20 > Attached file is output from ./fruconfig -x >=20 > From SSU, the Langley contains 10 FRU items, meanwhile 2 FRU=20 > items are displayable. >=20 > Thanks > Jeff Jef...@in... > BTW, I speak for myself, not for Intel Corp. >=20 |
|
From: Cress, A. R <and...@in...> - 2003-09-03 08:42:40
|
Jeff, That size returned isn't valid. The most likely cause is, as the utility message says, a wrong FRU/SDR diskette. fruconfig works on all Langleys except this one, and that must be the difference. The version should have been one that goes with BMC 48. =20 Which version of the FRU/SDR diskette was used on this system? Andy -----Original Message----- From: Zheng, Jeff=20 Sent: Tuesday, September 02, 2003 4:06 AM To: pan...@li... Subject: [Panicsel-developers] fruconfig fails on Langley Andy, I run fruconfig on Langley and it fails. Here is the result: [root@hpi util]# ./fruconfig fruconfig: version 1.5 -- BMC version 0.48, IPMI version 1.5 Mainboard FRU Size : 256 FRU size out of bounds: available=3D256 used=3D1832 Please apply the correct FRU/SDR diskette show_fru error -1 Attached file is output from ./fruconfig -x From SSU, the Langley contains 10 FRU items, meanwhile 2 FRU items are displayable. Thanks Jeff Jef...@in... BTW, I speak for myself, not for Intel Corp. |
|
From: Zheng, J. <jef...@in...> - 2003-09-03 00:41:05
|
Andy, What's the FRU/SDR diskette? Thanks Jeff Jef...@in... BTW, I speak for myself, not for Intel Corp. > -----Original Message----- > From: Cress, Andrew R=20 > Sent: 2003?9?3? 1:44 > To: Zheng, Jeff; pan...@li... > Subject: RE: [Panicsel-developers] fruconfig fails on Langley >=20 >=20 > Jeff, >=20 > That size returned isn't valid. The most likely cause is, as=20 > the utility message says, a wrong FRU/SDR diskette. =20 > fruconfig works on all Langleys except this one, and that=20 > must be the difference. > The version should have been one that goes with BMC 48. =20 > Which version of the FRU/SDR diskette was used on this system? >=20 > Andy >=20 > -----Original Message----- > From: Zheng, Jeff=20 > Sent: Tuesday, September 02, 2003 4:06 AM > To: pan...@li... > Subject: [Panicsel-developers] fruconfig fails on Langley >=20 >=20 > Andy, >=20 > I run fruconfig on Langley and it fails. Here is the result: > [root@hpi util]# ./fruconfig > fruconfig: version 1.5 > -- BMC version 0.48, IPMI version 1.5 > Mainboard FRU Size : 256 > FRU size out of bounds: available=3D256 used=3D1832 > Please apply the correct FRU/SDR diskette > show_fru error -1 >=20 > Attached file is output from ./fruconfig -x >=20 > From SSU, the Langley contains 10 FRU items, meanwhile 2 FRU=20 > items are displayable. >=20 > Thanks > Jeff Jef...@in... > BTW, I speak for myself, not for Intel Corp. >=20 |
|
From: Zheng, J. <jef...@in...> - 2003-09-02 10:18:16
|
Andy, I run fruconfig on Langley and it fails. Here is the result: [root@hpi util]# ./fruconfig fruconfig: version 1.5 -- BMC version 0.48, IPMI version 1.5 Mainboard FRU Size : 256 FRU size out of bounds: available=3D256 used=3D1832 Please apply the correct FRU/SDR diskette show_fru error -1 Attached file is output from ./fruconfig -x From SSU, the Langley contains 10 FRU items, meanwhile 2 FRU items are = displayable. Thanks Jeff Jef...@in... BTW, I speak for myself, not for Intel Corp. |
|
From: Cress, A. R <and...@in...> - 2003-07-31 14:56:25
|
panicsel 1.3.4 adds some new features (SerialOverLan, thresholds),
with two bugfixes (SetUser, ipmi_cmd_raw).
hpiutil 1.0.4 is new. The utiities are open-source (BSD license), but the
HPI library that it is tested with is closed source (Intel license).
Binaries of the HPI library are included in the tarball for testing on Intel
IPMI platforms. The source for these HPI utilities has been also added to
the OpenHPI project, but not all of the functions are supported in the
OpenHPI library yet.
See http://panicsel.sourceforge.net for the software.
A link to the Intel imb driver source has been added to the web page also.
Here are the changes:
07/24/03 ARCress
hpiutil-1.0.4.tar.gz: added parallel HPI utilities
07/30/03 ARCress ver 1.3.4
pefconfig v1.18: add SerialOverLan configuration
mod to SetUser, added GetBmcEthDevice,
use 'arping -I' if eth1.
ipmicmd.c: added serial-over-lan commands,
added GetThresholds, fix for ipmi_cmd_raw,
changed some error messages
sensor v1.8: add -t option for thresholds,
added sample Discovery routine (unfinished)
added ipmi_getdeviceid for completeness
Andy
|
|
From: Cress, A. R <and...@in...> - 2003-06-24 19:32:56
|
Here are the changes in this release.
06/24/03 ARCress ver 1.3.3
fruconfig.c: added Chassis fields
fruconfig.c: added errno.h (thanks to Travers Carter)
pefconfig.c: fixed EnablePef if startup delay not supported
pefconfig.c: added errno.h (thanks to Travers Carter)
wdt.c: progver 1.2 includes EMSGSIZE fix
ipmimv.c: ignore EMSGSIZE errno for get_wdt command
showsel.c: fix -w if log gets cleared
ipmicmd.c: always add an extra byte to _mv sresp for cc
Andy
|
|
From: Cress, A. R <and...@in...> - 2003-06-20 12:30:09
|
Thanks, that fix will be posted, along with some others, on Monday. Andy -----Original Message----- From: Travers Carter [mailto:tc...@no...] Sent: Thursday, June 19, 2003 9:13 PM To: pan...@li... Subject: [Panicsel-developers] util/wdt.c getopt in 1.3.2 Hi, The getopt string in util/wdt.c on line 166 is missing the debug (x) flag. -- Travers Carter - Noggin - http://www.noggin.com.au/ ------------------------------------------------------- This SF.Net email is sponsored by: INetU Attention Web Developers & Consultants: Become An INetU Hosting Partner. Refer Dedicated Servers. We Manage Them. You Get 10% Monthly Commission! INetU Dedicated Managed Hosting http://www.inetu.net/partner/index.php _______________________________________________ Panicsel-developers mailing list Pan...@li... https://lists.sourceforge.net/lists/listinfo/panicsel-developers |
|
From: Travers C. <tc...@no...> - 2003-06-20 01:14:27
|
Hi, The getopt string in util/wdt.c on line 166 is missing the debug (x) flag. -- Travers Carter - Noggin - http://www.noggin.com.au/ |
|
From: Travers C. <tc...@no...> - 2003-06-19 03:34:07
|
When building panicsel 1.3.2 on RedHat 9 I get the following error: /usr/src/redhat/BUILD/panicsel-1.3.2/util/fruconfig.c:120: undefined reference to `errno' And simillar for pefconfig.c util/fruconfig.c and util/pefconfig.c need to include errno.h Travers Carter - Noggin - http://www.noggin.com.au/ ------------------------------------------ diff -Naur panicsel-1.3.2/util/fruconfig.c panicsel-1.3.2-tc/util/fruconfig.c --- panicsel-1.3.2/util/fruconfig.c 2003-05-01 01:08:50.000000000 +1000 +++ panicsel-1.3.2-tc/util/fruconfig.c 2003-06-19 12:55:28.000000000 +1000 @@ -53,6 +53,7 @@ #include <syslog.h> #include <unistd.h> #include <string.h> +#include <errno.h> #include "ipmicmd.h" diff -Naur panicsel-1.3.2/util/pefconfig.c panicsel-1.3.2-tc/util/pefconfig.c --- panicsel-1.3.2/util/pefconfig.c 2003-04-08 23:11:27.000000000 +1000 +++ panicsel-1.3.2-tc/util/pefconfig.c 2003-06-19 12:55:44.000000000 +1000 @@ -89,6 +89,7 @@ #include <sys/socket.h> /* for Get_IPMac_Addr() */ #include <sys/ioctl.h> /* for Get_IPMac_Addr() */ #include <net/if.h> /* for Get_IPMac_Addr() */ +#include <errno.h> #include "ipmicmd.h" |
|
From: Cress, A. R <and...@in...> - 2003-04-08 16:59:02
|
Here are the changes in the panicsel 1.3.1 release. See http://panicsel.sourceforge.net for more information. Andy 04/08/03 ARCress ver 1.3.1 pefconfig 1.15: added -i option for eth interface imbapi.c: fix compile warnings, fix license text error ipmimv.c: fix problem with crontab or null-stdin invocations alarms.c: 1.1: added -i for Chassis ID function hwreset.c: 1.6: added -o for soft shutdown OS man pages: updated, added alarms.8 & wdt.8 UserGuide: updated with new man page info |
|
From: Cress, A. R <and...@in...> - 2003-04-08 16:56:40
|
I found the problem, in ipmimv.c it tries to include stdin on the select.
This is fixed in panicsel 1.3.1, just released.
Andy
-----Original Message-----
From: Meik Hellmund [mailto:Mei...@ma...]
Sent: Thursday, April 03, 2003 8:08 AM
To: pan...@li...
Subject: [Panicsel-developers] error in sensor
Hi,
I found a strange problem with sensor from panicsel-1.3.0,
linux 2.4.20, openIPMI drivers v18:
It works like a charm from the commandline but fails when called from
crontab.
## this a output snippet from "strace sensor" when it works:
open("/dev/ipmi0", O_RDWR) = 3
ioctl(3, 0x80046910, 0xbfffec6c) = 0
ioctl(3, 0x8014690d, 0xbfffec70) = 0
select(4, [0 3], NULL, NULL, {5, 0}) = 1 (in [3], left {4, 780000})
ioctl(3, I2OEVTGET, 0xbfffecc0) = 0
## and this happens when I try to run it from crontab:
open("/dev/ipmi0", O_RDWR) = 3
ioctl(3, 0x80046910, 0xbffff0e4) = 0
ioctl(3, 0x8014690d, 0xbffff0f0) = 0
select(4, [0 3], NULL, NULL, {5, 0}) = 1 (in [0], left {5, 0})
ioctl(3, I2OEVTGET, 0xbffff140) = -1 EAGAIN (Resource temporarily
unavailable)
I think there is some subtle error in the filedescriptor handling in
ipmicmd_mv(). Something goes wrong when stdin is redirected:
I can reproduce the error without crontab by simply
calling "sensor < /dev/null"
Cheers, Meik
--
Meik Hellmund
Institut fuer Mathematik, Uni Leipzig
e-mail: Mei...@ma...
http://www.math.uni-leipzig.de/~hellmund
-------------------------------------------------------
This SF.net email is sponsored by: ValueWeb:
Dedicated Hosting for just $79/mo with 500 GB of bandwidth!
No other company gives more support or power for your dedicated server
http://click.atdmt.com/AFF/go/sdnxxaff00300020aff/direct/01/
_______________________________________________
Panicsel-developers mailing list
Pan...@li...
https://lists.sourceforge.net/lists/listinfo/panicsel-developers
|
|
From: Cress, A. R <and...@in...> - 2003-04-04 00:08:47
|
Hmmm. It seems to have problems when stdin is null, regardless of driver
version.
I'll see what I can find out with gdb. Good feedback.
Thanks,
Andy
-----Original Message-----
From: Meik Hellmund [mailto:Mei...@ma...]
Sent: Thursday, April 03, 2003 8:08 AM
To: pan...@li...
Subject: [Panicsel-developers] error in sensor
Hi,
I found a strange problem with sensor from panicsel-1.3.0,
linux 2.4.20, openIPMI drivers v18:
It works like a charm from the commandline but fails when called from
crontab.
## this a output snippet from "strace sensor" when it works:
open("/dev/ipmi0", O_RDWR) = 3
ioctl(3, 0x80046910, 0xbfffec6c) = 0
ioctl(3, 0x8014690d, 0xbfffec70) = 0
select(4, [0 3], NULL, NULL, {5, 0}) = 1 (in [3], left {4, 780000})
ioctl(3, I2OEVTGET, 0xbfffecc0) = 0
## and this happens when I try to run it from crontab:
open("/dev/ipmi0", O_RDWR) = 3
ioctl(3, 0x80046910, 0xbffff0e4) = 0
ioctl(3, 0x8014690d, 0xbffff0f0) = 0
select(4, [0 3], NULL, NULL, {5, 0}) = 1 (in [0], left {5, 0})
ioctl(3, I2OEVTGET, 0xbffff140) = -1 EAGAIN (Resource temporarily
unavailable)
I think there is some subtle error in the filedescriptor handling in
ipmicmd_mv(). Something goes wrong when stdin is redirected:
I can reproduce the error without crontab by simply
calling "sensor < /dev/null"
Cheers, Meik
--
Meik Hellmund
Institut fuer Mathematik, Uni Leipzig
e-mail: Mei...@ma...
http://www.math.uni-leipzig.de/~hellmund
-------------------------------------------------------
This SF.net email is sponsored by: ValueWeb:
Dedicated Hosting for just $79/mo with 500 GB of bandwidth!
No other company gives more support or power for your dedicated server
http://click.atdmt.com/AFF/go/sdnxxaff00300020aff/direct/01/
_______________________________________________
Panicsel-developers mailing list
Pan...@li...
https://lists.sourceforge.net/lists/listinfo/panicsel-developers
|
|
From: Meik H. <Mei...@ma...> - 2003-04-03 13:10:55
|
Hi,
I found a strange problem with sensor from panicsel-1.3.0,
linux 2.4.20, openIPMI drivers v18:
It works like a charm from the commandline but fails when called from
crontab.
## this a output snippet from "strace sensor" when it works:
open("/dev/ipmi0", O_RDWR) = 3
ioctl(3, 0x80046910, 0xbfffec6c) = 0
ioctl(3, 0x8014690d, 0xbfffec70) = 0
select(4, [0 3], NULL, NULL, {5, 0}) = 1 (in [3], left {4, 780000})
ioctl(3, I2OEVTGET, 0xbfffecc0) = 0
## and this happens when I try to run it from crontab:
open("/dev/ipmi0", O_RDWR) = 3
ioctl(3, 0x80046910, 0xbffff0e4) = 0
ioctl(3, 0x8014690d, 0xbffff0f0) = 0
select(4, [0 3], NULL, NULL, {5, 0}) = 1 (in [0], left {5, 0})
ioctl(3, I2OEVTGET, 0xbffff140) = -1 EAGAIN (Resource temporarily unavailable)
I think there is some subtle error in the filedescriptor handling in
ipmicmd_mv(). Something goes wrong when stdin is redirected:
I can reproduce the error without crontab by simply
calling "sensor < /dev/null"
Cheers, Meik
--
Meik Hellmund
Institut fuer Mathematik, Uni Leipzig
e-mail: Mei...@ma...
http://www.math.uni-leipzig.de/~hellmund
|
|
From: Cress, A. R <and...@in...> - 2003-03-27 15:48:34
|
This release includes changes to conform the panicsel utilitiy source to autoconf/automake portability standards. Panicsel 1.3.0 also includes the following changes: * fruconfig: more bounds checking, * showsel: added savid for more efficient read loop if -w, * imb_api.h: morphed comments for some crazy compilers, * imbapi.c: morphed comments for some crazy compilers, * kern/bmcpanic-2.5.62.patch: new, from guomin See http://panicsel.sourceforge.net for more details and downloads. Andy |
|
From: Cress, A. R <and...@in...> - 2003-03-20 14:24:26
|
Guo Min,
Thanks for looking at this. This change really isn't what I meant, and that
note may have been too cryptic.
The problem with efficiency is that showsel still does a GetSelEntry() to
read every record in the SEL each time it is invoked. This can take a while
if the SEL is getting full. I think the answer will be to keep track of the
RecordID as well as the time, and (only if fwriteit) initialize the RecordID
to the saved value before starting the loop.
Having thought that far, I just made the above change for showsel 1.11.
Here is the patch that should do it.
Andy
--- panicsel/panicsel/util/showsel.c Thu Feb 27 22:15:32 2003
+++ panicsel_new/panicsel/util/showsel.c Tue Mar 11 16:38:50 2003
@@ -482,6 +482,7 @@
memset(pSelRecord, 0, sizeof(SEL_RECORD));
if (fwriteit) StartWriting(&savtime);
while( GetSelEntry( &RecordID, pSelRecord) == 0 ) {
+ if (( fwriteit && pSelRecord->timestamp >= savtime ) ||
!fwriteit ){
if (mytype == 0xff || pSelRecord->sensor_type == mytype) {
/* set dtype, used as array index below */
if (pSelRecord->sensor_type > 0x29) dtype = 0;
@@ -568,14 +569,13 @@
pSelRecord->event_data3 );
printf(output);
if (fwriteit) {
- /* Only write newer records */
- if (pSelRecord->timestamp > savtime) {
/* Write the given SEL record to the syslog. */
syslog(LOG_INFO,output);
- savtime = pSelRecord->timestamp;
- }
+ if (pSelRecord->timestamp > savtime)
+ savtime = pSelRecord->timestamp;
}
} /*endif match*/
+ }
if( pSelRecord->record_id == -1 )
break;
if( RecordID == pSelRecord->record_id )
----------------------------------------------------------------------------
--------------
Thanks
Guo Min
The content of this email message solely contains my own personal views,
and not those of my employer.
|
|
From: Cress, A. R <and...@in...> - 2003-03-10 14:59:55
|
This needs to go either way. With a test for rpm version.
For RH 8.0 the rpmbuild utility exists.
For other distros, and RH < 8.0, "rpm -bs" is correct.
something like:
rpmbuild --version >/dev/null 2>&1
if [ $? -eq 0 ]
then
rpmbuild -bs
else
rpm -bs
fi
Andy
-----Original Message-----
From: Guo, Min
Sent: Sunday, March 09, 2003 8:57 PM
To: pan...@li...
Subject: [Panicsel-developers] makefile error
Hi
Platform Cossbay, Redhat 8.0. RPM version 4.1
When I run the make ,the system outputs
rpm -bs panicsel.spec
-bs: unknown option
make: *** [srpm] Error 1
So change the rpm to rpmbuild, we can compile the source
successfully.
Thanks
Guo Min
-------------------------------------------------------
This SF.net email is sponsored by: Etnus, makers of TotalView, The debugger
for complex code. Debugging C/C++ programs can leave you feeling lost and
disoriented. TotalView can help you find your way. Available on major UNIX
and Linux platforms. Try it free. www.etnus.com
_______________________________________________
Panicsel-developers mailing list
Pan...@li...
https://lists.sourceforge.net/lists/listinfo/panicsel-developers
|
--- showsel.c.orig Thu Mar 20 09:17:41 2003
+++ showsel.c Thu Mar 20 09:13:25 2003
@@ -30,6 +30,8 @@
* 02/18/03 Andy Cress v1.9 trim out some fields so it fits on 1 line,
* decode Boot Event subcodes
* 02/27/03 Andy Cress v1.10 change OS Crit Stop decoding to handle new
types
+ * 03/20/03 Andy Cress v1.11 for -w, save id also, so we don't have to
start
+ * over at the beginning each time.
*/
/*M*
Copyright (c) 2002, Intel Corporation
@@ -73,8 +75,8 @@
{
short record_id;
uchar record_type;
- int timestamp;
- ushort generator_id;
+ uint timestamp;
+ short generator_id;
uchar evm_rev; //event message revision
uchar sensor_type;
uchar sensor_number;
@@ -97,14 +99,15 @@
#define MIN_FREE 128 /* minimal bytes of free SEL space */
char progname[] = "showsel";
-char progver[] = "1.10";
+char progver[] = "1.11";
char idxfile[] = "/usr/share/panicsel/sel.idx";
char fdebug = 0;
char fall = 1;
char fwritesel = 0;
char fclearsel = 0;
char fonlyver = 0;
-int savtime = 0;
+uint savtime = 0;
+short savid = 0;
static const char *sensor_types[] = {
/* 00h */ "reserved",
@@ -388,35 +391,38 @@
} /* end GetSelEntry() */
-void StartWriting(int *plasttime)
+void StartWriting(uint *plasttime, short *plastid)
{
FILE *fd;
+ uint lasttime;
+ short lastid;
int ret;
+ lasttime = 0;
+ lastid = 0;
// Open the index file
fd = fopen(idxfile,"r");
- if (fd == NULL) {
- *plasttime = 0;
- } else {
- // Read the file & get savtime
- ret = fscanf(fd,"%x",&savtime);
- if (fdebug) printf("StartWriting: ret = %d, savtime = %d\n",
- ret,savtime);
- if (ret != 1) savtime = 0;
-
+ if (fd != NULL) {
+ // Read the file, get savtime & savid
+ ret = fscanf(fd,"%x %x",&lasttime,&lastid);
fclose(fd);
}
+ if (fdebug) printf("StartWriting: ret = %d, savtime = %x, savid =
%x\n",
+ ret,lasttime,(ushort)lastid);
+ *plasttime = lasttime;
+ *plastid = lastid;
// Open syslog
openlog( "SEL: ", LOG_CONS, LOG_KERN);
return;
}
-void StopWriting(int lasttime)
+void StopWriting(uint lasttime, short lastid)
{
FILE *fd;
+ // Rewrite the saved time & record id
fd = fopen(idxfile,"w");
if (fd != NULL) {
- fprintf(fd,"%x\n",lasttime);
+ fprintf(fd,"%x %x\n",lasttime,lastid);
fclose(fd);
}
// Close syslog
@@ -465,7 +471,7 @@
void ReadSEL(uchar mytype, char fwriteit)
{
- short RecordID = 0; //first record
+ short RecordID = 0; /* 0 = first record, -1 = end */
SEL_RECORD selRecord;
SEL_RECORD *pSelRecord = &selRecord;
uchar dtype;
@@ -480,7 +486,10 @@
uchar timebuf[40];
memset(pSelRecord, 0, sizeof(SEL_RECORD));
- if (fwriteit) StartWriting(&savtime);
+ if (fwriteit) {
+ StartWriting(&savtime,&savid);
+ RecordID = savid;
+ }
while( GetSelEntry( &RecordID, pSelRecord) == 0 ) {
if (mytype == 0xff || pSelRecord->sensor_type == mytype) {
/* set dtype, used as array index below */
@@ -573,8 +582,9 @@
/* Write the given SEL record to the syslog. */
syslog(LOG_INFO,output);
savtime = pSelRecord->timestamp;
+ savid = pSelRecord->record_id;
}
- }
+ } /*endif fwriteit*/
} /*endif match*/
if( pSelRecord->record_id == -1 )
break;
@@ -582,7 +592,7 @@
break;
memset(pSelRecord, 0, sizeof(SEL_RECORD));
} /*endwhile*/
- if (fwriteit) StopWriting(savtime);
+ if (fwriteit) StopWriting(savtime,savid);
} /* end ReadSEL()*/
ushort vfree;
> -----Original Message-----
> From: Guo, Min
> Sent: Tuesday, March 11, 2003 4:00 AM
> To: Cress, Andrew R
> Cc: pan...@li...
> Subject: About the showsel in Todo List.
>
> Hi ,Andy
>
> I don't understand the following TODO list clearly, I think it means
> that we should insert the new SEL record plus the last record (has been
> written to syslog last time) to syslog,if write_to_syslog,we need not go
> so many judgment code to make showsel more efficient,so that customer can
> locate the latest SEL log promptly, is that right?
>
> "make showsel scan for syslog more efficient.
> Currently reads all SEL records if normal or if write_to_syslog;
> then if write_to_syslog, write newer SEL records to syslog.
> Change: if write_to_syslog, read last SEL plus new SEL records
> only."
>
> If so ,then just apply the following patch,I have tested it on my
> langley machine.
> --------------------------------------------------------------------------
> ------------------------------
> --- panicsel/panicsel/util/showsel.c Thu Feb 27 22:15:32 2003
> +++ panicsel_new/panicsel/util/showsel.c Tue Mar 11 16:38:50 2003
> @@ -482,6 +482,7 @@
> memset(pSelRecord, 0, sizeof(SEL_RECORD));
> if (fwriteit) StartWriting(&savtime);
> while( GetSelEntry( &RecordID, pSelRecord) == 0 ) {
> + if (( fwriteit && pSelRecord->timestamp >= savtime ) ||
> !fwriteit ){
> if (mytype == 0xff || pSelRecord->sensor_type == mytype) {
> /* set dtype, used as array index below */
> if (pSelRecord->sensor_type > 0x29) dtype = 0;
> @@ -568,14 +569,13 @@
> pSelRecord->event_data3 );
> printf(output);
> if (fwriteit) {
> - /* Only write newer records */
> - if (pSelRecord->timestamp > savtime) {
> /* Write the given SEL record to the syslog.
> */
> syslog(LOG_INFO,output);
> - savtime = pSelRecord->timestamp;
> - }
> + if (pSelRecord->timestamp > savtime)
> + savtime = pSelRecord->timestamp;
> }
> } /*endif match*/
> + }
> if( pSelRecord->record_id == -1 )
> break;
> if( RecordID == pSelRecord->record_id )
> --------------------------------------------------------------------------
> ----------------
>
> Thanks
> Guo Min
> The content of this email message solely contains my own personal views,
> and not those of my employer.
>
|
|
From: Guo, M. <mi...@in...> - 2003-03-11 09:02:10
|
Hi ,Andy
I don't understand the following TODO list clearly, I think it means
that we should insert the new SEL record plus the last record (has been
written to syslog last time) to syslog,if write_to_syslog,we need not go
so many judgment code to make showsel more efficient,so that customer can
locate the latest SEL log promptly, is that right?
"make showsel scan for syslog more efficient.
Currently reads all SEL records if normal or if write_to_syslog;
then if write_to_syslog, write newer SEL records to syslog.
Change: if write_to_syslog, read last SEL plus new SEL records
only."
If so ,then just apply the following patch,I have tested it on my
langley machine.
----------------------------------------------------------------------------
----------------------------